AppconsentClear class
AppconsentClear is the entry point to interract with our CMP.
You first configure an instance of it calling AppconsentClear.setup. Then use presentNotice to display the CMP UI if needed.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
appTrackingAuthorizationGiven
→ Future<
bool> -
iOS only
no setter
-
appTrackingAuthorizationStatus
→ Future<
int> -
iOS only
no setter
-
appTrackingIsAvailable
→ Future<
bool> -
iOS only
no setter
-
checkForUpdate
→ Future<
bool> -
Returns
trueif an update to the Notice and consents is needed.no setter -
consentGiven
→ Future<
bool> -
Returns
trueif user has already saved their preferences.no setter -
isSubjectToGDPR
→ Future<
bool> -
Returns
trueif user is subject to GDPR. It depends on forceApplyGDPR and phone's locale.no setter
Static Methods
-
clearConsent(
) → Future< void> - Clears user consents preferences.
-
consentableAllowed(
int iabId, ConsentableType type) → Future< bool> -
Returns
trueif consentable of ConsentableTypetypewith IDìabIdis ALLOWED. -
extraConsentableAllowed(
String extraId) → Future< bool> -
Returns
trueif an extra consentable referenced byextraIdis allowed. -
extraVendorAllowed(
String extraId) → Future< bool> -
Returns
trueif an extra vendor referenced byextraIdis allowed. -
presentNotice(
bool force) → Future< void> - Displays the CMP Notice if needed.
-
setup(
String appKey, bool forceApplyGDPR, bool forceATT, {bool fullscreen = false, String dedicatedEndpointURL = "", String dedicatedAssetsURL = ""}) → Future< void> - Setup the AppConsent CMP.